################################################################################
#  GTChat 0.95 Alpha Plugin                                                    #
#  Written for release 20030110                                                #
#  Author: Lord                                                                #
#                                                                              #
#  This plugin shows the user who have entered in the previous 24 hours        #
#                                                                              # 
#                                                                              #
################################################################################

package GTChat::Plugins::VarHandlers::lastlogincheck;
use strict;
use vars qw(@ISA);

@ISA = ('GTChat::Enum');

bless({
	template_var_handlers => {
		'userlastlog' => \&handler,
		
		
	},
	opened => 0,
	index => -1,
});



sub handler
{
	my($self,$main,$var) = @_;

	my $enum=$main->{modules}{'sourcedir::Enum.pm'};
        
	$self->{main} = $main;

	if ($var =~ /userlastlog/)
	{
		$self->{list} = $main->getLastLoginUsers('');
		$main->{template_vars}{userlastlog} = $self;
	}
	
}


sub open
{
	my $self=shift;
	
	$self->close if $self->{opened};
	
	$self->{index} = -1;
	$self->{opened} = 1;
}

sub hasNext
{
	my $self=shift;
	return ($self->{opened} && $self->{index}<$#{$self->{list}});
}

sub next
{
	my $self=shift;

	return undef if (!$self->{opened} || $self->{index}>=$#{$self->{list}});
	
	$self->{index}++;

	$self->{list}[$self->{index}] =~ s/[\n\r]//g;

	my %ret = ();

	my ($count,$lastlogin,$nickname,$username,$online,$registration,$test,$onlinetime) = split(/\|/,$self->{list}[$self->{index}]);
	my $seconds = $onlinetime % 60;
	my $minutes = (($onlinetime - $seconds) / 60) % 60;
	my $hours = ((($onlinetime - $seconds) - ($minutes * 60)) / 3600) % 24;
	my $days = ((($onlinetime - $seconds) - ($minutes * 60) - ($hours * 3600)) / 86400);
	

	$ret{count} = $count;
	$ret{nickname} = $nickname;
	$ret{username} = $username;
	$ret{online} = $online;
        $ret{lastlogin} = $lastlogin;
        $ret{days} = $days;
        $ret{hours} = $hours;
        $ret{minutes} = $minutes;
        $ret{seconds} = $seconds;
        $ret{registration} = $registration;
        $ret{email} = $test;
        $ret{past} = $onlinetime;
	return \%ret;
}

sub close
{
	my $self=shift;
	
	$self->{opened}=0;
}

sub getLastLoginUsers
{
	my($main,$var) = @_;

	$main->open(local *FILE,$main->translateName('memberdir::memberlist.txt')) || return [];
	my @users=<FILE>;
	$main->close(*FILE);

	my @lastloginusers=();
	foreach (@users)
	{
		$_ =~ s/[\n\r]//g;

		my($nickname,$username) = split(/\|/,$_);
		my $user = $main->loadUser($username);
		my $online = ($main->loadOnlineInfo($user->{name},$user) ? 1 : 0);
		my $lastlogin = $user->{lastlogin};
		my $registration = $user->{registration};
		my $test = $user->{email};
		my $onlinetime = $main->{runtime}{now} - $user->{lastlogin};
		next if($user->{group} eq '-1');
		push @lastloginusers, $user->{lastlogin}."|".$nickname."|".$username."|".$online."|".$lastlogin."|".$registration."|".$test."|".$onlinetime;
	}

	@lastloginusers = sort(SortByTime @lastloginusers);

	my @users=();
	my $count=0;
	foreach (@lastloginusers)
	{
		$count++;
		$_ =~ s/[\n\r]//g;
		my($nickname,$username,$online,$away,$lastlogin,$registration,$test,$onlinetime) = split(/\|/,$_);
		push @users, $count."|".$nickname."|".$username."|".$online."|".$lastlogin."|".$registration."|".$test."|".$onlinetime;
		last if($count == $var);
	}

	return \@users;
	
	
}

sub SortByTime
{
	if($a > $b)
	{
		return 1;
	}
	elsif($a == $b)
	{
		return 0;
	}
 	else
	{
		return -1;
	}
}
